# IpsumHeroes

*Where lorem ipsum meets the legends of history.*

IpsumHeroes is a playful **lorem ipsum generator** that sprinkles placeholder text with the names and quotes of **history’s luminaries and heroes**. Perfect for developers, designers, and writers who want their filler text to be more inspiring.

## Features

- Generate standard lorem ipsum text enhanced with historical luminaries
- Currently supporting luminaries from: anctient history , science or music 
- Luminary text available in English, Dutch, German, French and Spanish
- Adding your own dataset with heroes in one ore more languages
- Lightweight and easy to integrate into Python projects

Adjustable:
- number of sentences
- number of paragraphs
- number of sentence sections
- number of sentence sections
- number of words per sentence section
- number of sentences ending in a dot, question mark or exclamation mark 
- indentation
- tags (to support XML, HTML etc)
- wrapping colums
- and more things to tweak ...

## Installation

```bash
pip install ipsumheroes
```

